@@ -19,6 +19,7 @@
  
 imports.gi.versions.Gst = '1.0';
 
+const Gettext = imports.gettext;
 const _ = imports.gettext.gettext;
 const Gdk = imports.gi.Gdk;
 const GdkPixbuf = imports.gi.GdkPixbuf;
@@ -37,8 +38,10 @@ const Waveform = imports.waveform;
 
 let activeProfile = null;
 let audioProfile = null;
+let displayTime = null;
 let grid = null;
 let groupGrid;
+let header;
 let list = null;
 let loadMoreButton = null;
 let offsetController = null;
@@ -86,6 +89,7 @@ const MainWindow = new Lang.Class({
      _init: function(params) {
         audioProfile = new AudioProfile.AudioProfile();
         offsetController = new FileUtil.OffsetController;
+        displayTime = new FileUtil.DisplayTime;
         view = new MainView();
         play = new Play.Play();
         
@@ -96,15 +100,12 @@ const MainWindow = new Lang.Class({
                                        default_height: 480 });
         this.parent(params);
 
-        let header = new Gtk.HeaderBar({ hexpand: true,
-                                         show_close_button: true });
+        header = new Gtk.HeaderBar({ hexpand: true,
+                                     show_close_button: true });
         this.set_titlebar(header);
+        header.get_style_context().add_class('titlebar');
 
-        recordButton = new RecordButton({ label: _("Record"),
-                                          margin_bottom: 4,
-                                          margin_top: 6,
-                                          margin_left: 6,
-                                          margin_right: 6 });
+        recordButton = new RecordButton({ label: _("Record") });
         recordButton.get_style_context().add_class('destructive-action');
         header.pack_start(recordButton);
 
@@ -246,6 +247,7 @@ const MainView = new Lang.Class({
         this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                          height_request: 36,
                                          width_request: 775,
+                                         hexpand: true,
                                          name: "recordGrid" });
         this.groupGrid.add(this.recordGrid);
         
@@ -275,21 +277,22 @@ const MainView = new Lang.Class({
         
         this._boxRecord.pack_start(this.recordTimeLabel, false, true, 0);
         
-        this.toolbarStart = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
+        this.toolbarStart = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL, expand: false });
         this.toolbarStart.get_style_context().add_class(Gtk.STYLE_CLASS_LINKED);
 
         // finish button (stop recording)
-        let stopRecord = new Gtk.Button({ label: _("Finish"),
+        let stopRecord = new Gtk.Button({ label: _("Done"),
                                           margin_bottom: 4,
                                           margin_top: 6,
                                           margin_left: 6,
                                           margin_right: 6,
                                           valign: Gtk.Align.CENTER,
+                                          halign: Gtk.Align.FILL,
                                           hexpand: true });
         stopRecord.get_style_context().add_class('text-button');
         stopRecord.connect("clicked", Lang.bind(this, this.onRecordStopClicked));
         this.toolbarStart.pack_start(stopRecord, true, true, 0);
-        this.recordGrid.attach(this.toolbarStart, 5, 1, 1, 2);
+        this.recordGrid.attach(this.toolbarStart, 5, 1, 2, 2);
     },
      
     scrolledWinAdd: function() {    
@@ -314,7 +317,16 @@ const MainView = new Lang.Class({
                   
         this.groupGrid.add(this._scrolledWin);
         this._scrolledWin.show();
+        let itemNumber = list.getItemCount();
+        let title;
         
+        // Translators: This is the title in the headerbar
+        if (sounds > 0) {
+            title = Gettext.ngettext("%d Recorded Sound",
+                                     "%d Recorded Sounds", 
+                                      sounds).format(sounds);
+        }
+        header.set_title(title);
         this.listBox = null;
         this._startIdx = 0;
         this._endIdx = offsetController.getEndIdx();
@@ -347,18 +359,33 @@ const MainView = new Lang.Class({
                 this.listBox.add(this.rowGrid);
                 this.rowGrid.show();                
                 let rtl = Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL;
-
+                
+                this.placeholderImage = Gtk.Image.new();
+                this.placeholderImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
+                                                            'media-playback-start-symbolic',
+                                                         Gtk.IconSize.BUTTON);
+                this._placeholderButton = new Gtk.Button({ hexpand: true,
+                                                           vexpand: true,
+                                                           name: "PlaceholderButton" });
+                this._placeholderButton.set_image(this.placeholderImage);
+                this.rowGrid.attach(this._placeholderButton, 0, 0, 2, 2);
+                this._placeholderButton.set_no_show_all(true);
+                this.placeholderImage.show();
+                this._placeholderButton.show();
+                this._placeholderButton.get_style_context().add_class("dim-label");
+                
                 // play button
                 this.playImage = Gtk.Image.new();
                 this.playImage.set_from_icon_name(rtl ? 'media-playback-start-rtl-symbolic' :
                                                         'media-playback-start-symbolic',
                                                   Gtk.IconSize.BUTTON);
-                this._playListButton = new Gtk.Button({ hexpand: false,
+                this._playListButton = new Gtk.Button({ hexpand: true,
                                                         vexpand: true,
                                                         name: "PlayButton" });
                 this._playListButton.set_image(this.playImage);
                 this._playListButton.set_tooltip_text(_("Play"));
-                this.rowGrid.attach(this._playListButton, 0, 0, 1, 2);
+                this._playListButton.get_style_context().add_class("toolbar");
+                this.rowGrid.attach(this._playListButton, 0, 0, 2, 2);
                 this._playListButton.hide();
                 this._playListButton.connect('clicked', Lang.bind(this,
                     function(){
@@ -373,12 +400,13 @@ const MainView = new Lang.Class({
                 // pause button
                 this.pauseImage = Gtk.Image.new();
                 this.pauseImage.set_from_icon_name('media-playback-pause-symbolic', Gtk.IconSize.BUTTON);
-                this._pauseListButton = new Gtk.Button({ hexpand: false,
+                this._pauseListButton = new Gtk.Button({ hexpand: true,
                                                          vexpand: true,
                                                          name: "PauseButton" });
                 this._pauseListButton.set_image(this.pauseImage);
                 this._pauseListButton.set_tooltip_text(_("Pause"));
-                this.rowGrid.attach(this._pauseListButton, 0, 0, 1, 2);
+                this.rowGrid.attach(this._pauseListButton, 0, 0, 2, 2);
+                this._pauseListButton.get_style_context().add_class("toolbar");
                 this._pauseListButton.hide();
                 this._pauseListButton.connect('clicked', Lang.bind(this,
                     function(){
@@ -399,13 +427,13 @@ const MainView = new Lang.Class({
                 let markup = ('<b>'+ this._files[i].fileName + '</b>');
                 this._fileName.label = markup;
                 this._fileName.set_no_show_all(true);
-                this.rowGrid.attach(this._fileName, 1, 0, 10, 3);
+                this.rowGrid.attach(this._fileName, 3, 0, 10, 3);
                 this._fileName.show();
                 
                 this._playLabelBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
                                                    name: "PlayLabelBox",
                                                    height_request: 45 });
-                this.rowGrid.attach(this._playLabelBox, 1, 1, 10, 1);
+                this.rowGrid.attach(this._playLabelBox, 3, 1, 5, 1);
                 this._playLabelBox.show();       
                 this.playDurationLabel = new Gtk.Label({ margin_left: rtl ? 0 : 15,
                                                          margin_right: rtl ? 15 : 0,
@@ -434,15 +462,27 @@ const MainView = new Lang.Class({
                 this._playLabelBox.pack_start(this.playTimeLabel, false, true, 0);
                 this.playTimeLabel.hide();
                 
+                //Date Modified label
+                this.dateModifiedLabel = new Gtk.Label({ margin_left: 15,
+                                                         margin_right: 15,
+                                                         halign: Gtk.Align.END,
+                                                         valign: Gtk.Align.CENTER,
+                                                         margin_top: 5,
+                                                         name: "dateModifiedLabel" });
+                this.dateModifiedLabel.label = this._files[i].dateModified;
+                this.dateModifiedLabel.get_style_context().add_class('dim-label');
+                this.rowGrid.attach(this.dateModifiedLabel, 3, 1, 6, 1);
+                this.dateModifiedLabel.show();
+                
                 this.waveFormGrid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                                    height_request: 45,
-                                                   width_request: 350,
+                                                   width_request: 300,
                                                    valign: Gtk.Align.FILL,
                                                    hexpand: true,
                                                    vexpand: true,
                                                    name: "WaveFormGrid" });
                 this.waveFormGrid.set_no_show_all(true);
-                this.rowGrid.attach(this.waveFormGrid, 11, 1, 18, 2);
+                this.rowGrid.attach(this.waveFormGrid, 12, 1, 17, 2);
                 this.waveFormGrid.show();
                 
                 // info button
@@ -460,7 +500,7 @@ const MainView = new Lang.Class({
                     }));
                 this._info.set_tooltip_text(_("Info"));
                 this._info.get_style_context().add_class(rtl ? "toolbarEnd" : "toolbarSecond");
-                this.rowGrid.attach(this._info, 29, 0, 1, 2);
+                this.rowGrid.attach(this._info, 27, 0, 1, 2);
                 this._info.hide();
 
                 // delete button
@@ -472,7 +512,7 @@ const MainView = new Lang.Class({
                         this._deleteFile(this.listBox.get_selected_row());
                     }));
                 this._delete.set_tooltip_text(_("Delete"));
-                this.rowGrid.attach(this._delete, 30, 0, 1, 2);
+                this.rowGrid.attach(this._delete, 28, 0, 1, 2);
                 this._delete.get_style_context().add_class(rtl ? "toolbarSecond" : "toolbarEnd");
                 this._delete.hide();
                 
@@ -537,6 +577,11 @@ const MainView = new Lang.Class({
                     
                     if (!alwaysShow)
                         child.hide();
+                    
+                    if (child.name == "PauseButton") {
+                        child.hide();
+                        child.sensitive = false;
+                    } 
                         
                     if (child.name == "PlayLabelBox") {
                         child.show();
@@ -580,6 +625,11 @@ const MainView = new Lang.Class({
                     if (!alwaysShow)
                         child.sensitive = true;
                         
+                    if (child.name == "PauseButton") {
+                        child.hide();
+                        child.sensitive = false;
+                    } 
+                        
                     if (child.name == "WaveFormGrid")
                         child.sensitive = true;
                 }));
@@ -606,7 +656,7 @@ const MainView = new Lang.Class({
     _deleteFile: function(selected) {
         this._selected = selected;
         let fileToDelete = this._getFileFromRow(this._selected);
-        fileToDelete.delete_async(GLib.PRIORITY_DEFAULT, null, null);
+        fileToDelete.trash_async(GLib.PRIORITY_DEFAULT, null, null);
     },
     
     loadPlay: function(selected) {
@@ -703,7 +753,6 @@ const MainView = new Lang.Class({
                     }
                 }));
             listRow.set_property("width-request", width);
-            log(this.get_allocated_width());
             
             if (this.activeState != PipelineStates.PAUSED) {
                 wave = new Waveform.WaveForm(this.wFGrid, selFile);
@@ -760,7 +809,7 @@ const EncoderComboBox = new Lang.Class({
         
         for (let i = 0; i < combo.length; i++)
             this.append_text(combo[i]);
-            
+        this.set_property('valign', Gtk.Align.CENTER);  
         this.set_sensitive(true);
         this.set_active(activeProfile);
         this.connect("changed", Lang.bind(this, this._onComboBoxTextChanged));
@@ -778,7 +827,6 @@ const LoadMoreButton = new Lang.Class({
     _init: function() {
         this.parent();
         this._block = false;
-
         this.label = _("Load More");                                       
         this.get_style_context().add_class('documents-load-more');
     },
